Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExtendedCommitCodec ¶
ExtendedCommitCodec is an autogenerated mock type for the ExtendedCommitCodec type
func NewExtendedCommitCodec ¶
func NewExtendedCommitCodec(t interface {
mock.TestingT
Cleanup(func())
}) *ExtendedCommitCodec
NewExtendedCommitCodec creates a new instance of ExtendedCommitCodec. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*ExtendedCommitCodec) Decode ¶
func (_m *ExtendedCommitCodec) Decode(_a0 []byte) (types.ExtendedCommitInfo, error)
Decode provides a mock function with given fields: _a0
func (*ExtendedCommitCodec) Encode ¶
func (_m *ExtendedCommitCodec) Encode(_a0 types.ExtendedCommitInfo) ([]byte, error)
Encode provides a mock function with given fields: _a0
type VoteExtensionCodec ¶
VoteExtensionCodec is an autogenerated mock type for the VoteExtensionCodec type
func NewVoteExtensionCodec ¶
func NewVoteExtensionCodec(t interface {
mock.TestingT
Cleanup(func())
}) *VoteExtensionCodec
NewVoteExtensionCodec creates a new instance of VoteExtensionCodec. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*VoteExtensionCodec) Decode ¶
func (_m *VoteExtensionCodec) Decode(_a0 []byte) (types.OracleVoteExtension, error)
Decode provides a mock function with given fields: _a0
func (*VoteExtensionCodec) Encode ¶
func (_m *VoteExtensionCodec) Encode(ve types.OracleVoteExtension) ([]byte, error)
Encode provides a mock function with given fields: ve